@@ -5,6 +5,11 @@ import numpy as np
 import joblib
 
 from supervised.algorithms.algorithm import BaseAlgorithm
+from supervised.algorithms.registry import (
+    BINARY_CLASSIFICATION,
+    MULTICLASS_CLASSIFICATION,
+    REGRESSION,
+)
 from supervised.utils.config import LOG_LEVEL
 
 logger = logging.getLogger(__name__)
@@ -47,34 +52,30 @@ class SklearnAlgorithm(BaseAlgorithm):
         self.uid = json_desc.get("uid", self.uid)
         self.params = json_desc.get("params", self.params)
 
+    def predict(self, X):
+        if self.params["ml_task"] == BINARY_CLASSIFICATION:
+            return self.model.predict_proba(X)[:, 1]
+        elif self.params["ml_task"] == MULTICLASS_CLASSIFICATION:
+            return self.model.predict_proba(X)
+        return self.model.predict(X)
+
 
 class SklearnTreesClassifierAlgorithm(SklearnAlgorithm):
     def __init__(self, params):
         super(SklearnTreesClassifierAlgorithm, self).__init__(params)
 
     def fit(self, X, y):
-        # logger.debug("SklearnTreesClassifierAlgorithm.fit")
         self.model.fit(X, np.ravel(y))
         if hasattr(self.model, "n_estimators"):
             self.model.n_estimators += self.trees_in_step
 
-    def predict(self, X):
-        # logger.debug("SklearnTreesClassifierAlgorithm.predict")
-        if "num_class" in self.params:
-            return self.model.predict_proba(X)
-        return self.model.predict_proba(X)[:, 1]
-
 
+# TODO refactor
 class SklearnTreesRegressorAlgorithm(SklearnAlgorithm):
     def __init__(self, params):
         super(SklearnTreesRegressorAlgorithm, self).__init__(params)
 
     def fit(self, X, y):
-        # logger.debug("SklearnTreesRegressorAlgorithm.fit")
         self.model.fit(X, np.ravel(y))
         if hasattr(self.model, "n_estimators"):
             self.model.n_estimators += self.trees_in_step
-
-    def predict(self, X):
-        # logger.debug("SklearnTreesRegressorAlgorithm.predict")
-        return self.model.predict(X)
