@@ -22,7 +22,7 @@ from supervised.tuner.mljar_tuner import MljarTuner
 from supervised.ensemble import Ensemble
 from supervised.utils.additional_metrics import AdditionalMetrics
 from supervised.utils.config import LOG_LEVEL
-
+from supervised.utils.leaderboard_plots import LeaderboardPlots
 from supervised.preprocessing.exclude_missing_target import ExcludeRowsMissingTarget
 
 logging.basicConfig(
@@ -51,10 +51,13 @@ class AutoML:
         model_time_limit=None,
         algorithms=[
             "Baseline",
+            "Linear",
             "Decision Tree",
             "Random Forest",
+            "Extra Trees",
             "LightGBM",
             "Xgboost",
+            "CatBoost",
         ],
         tuning_mode="Sport",
         train_ensemble=True,
@@ -67,6 +70,7 @@ class AutoML:
         },
         verbose=True,
         ml_task=None,
+        explain_level=2,
         seed=1,
     ):
         """
@@ -114,6 +118,10 @@ class AutoML:
         If number of values in the target will be between 2 and 20 (included), then task will be set to `"multiclass_classification"`.
         In all other casses, the task is set to `"regression"`.
         
+        :param explain_level: The level of explanations included to each model.
+        `explain_level = 0` means no explanations
+        `explain_level = 1` means produce importance plot (with permutation method), for decision trees produce tree plots, for linear models save coefficients
+        `explain_level = 2` the same as for `1` plus SHAP explanations
         :param seed: The seed for random generator.
         
         """
@@ -160,6 +168,7 @@ class AutoML:
 
         self._results_path = results_path
         self._set_results_dir()
+        self._explain_level = explain_level
 
     def set_tuning_mode(self, mode="Normal"):
         if mode == "Sport":
@@ -273,6 +282,9 @@ class AutoML:
         algo_cnt = len(self._algorithms)
         if "Baseline" in self._algorithms:
             algo_cnt -= 1
+        if "Linear" in self._algorithms:
+            algo_cnt -= 1
+
         self._estimated_models_to_check = algo_cnt * self._start_random_models
         if self._estimated_models_to_check > self._top_models_to_improve:
             self._estimated_models_to_check += (
@@ -281,6 +293,8 @@ class AutoML:
 
         if "Baseline" in self._algorithms:
             self._estimated_models_to_check += 1
+        if "Linear" in self._algorithms:
+            self._estimated_models_to_check += 1
 
         if self._model_time_limit is not None:
             k = self._validation.get("k_folds", 1.0)
@@ -646,6 +660,7 @@ class AutoML:
                 self._algorithms,
                 self._ml_task,
                 self._validation,
+                self._explain_level,
                 self._seed,
             )
 
@@ -653,6 +668,19 @@ class AutoML:
             generated_params = tuner.get_not_so_random_params(X_train, y_train)
             self._del_data_variables(X_train, y_train)
 
+            # Shuffle generated params
+            # do not shuffle Baseline, Linear and Decision Trees
+            dont_shuffle = []
+            to_shuffle = []
+            for p in generated_params:
+                if p["learner"]["model_type"] in ["Baseline", "Linear", "Decision Tree"]:
+                    dont_shuffle += [p]
+                else:
+                    to_shuffle += [p]
+            
+            np.random.shuffle(to_shuffle)
+            generated_params = dont_shuffle + to_shuffle
+            
             for params in generated_params:
                 self.train_model(params)
             # hill climbing
@@ -683,7 +711,7 @@ class AutoML:
 
             ldb = self.get_leaderboard()
             ldb.to_csv(os.path.join(self._results_path, "leaderboard.csv"), index=False)
-
+            
             # save report
             ldb["Link"] = [f"[Results link]({m}/README.md)" for m in ldb["name"].values]
             ldb.insert(loc=0, column="Best model", value="")
@@ -693,6 +721,8 @@ class AutoML:
             with open(os.path.join(self._results_path, "README.md"), "w") as fout:
                 fout.write(f"# AutoML Leaderboard\n\n")
                 fout.write(tabulate(ldb.values, ldb.columns, tablefmt="pipe"))
+                LeaderboardPlots.compute(ldb, self._results_path, fout)
+
         except Exception as e:
             raise e
         finally:
